@@ -24,7 +24,6 @@ class pysubsonic:
         full_url = f"{self.url}/rest/{endpoint}?{self.make_bad_auth_params()}&c={self.client}&v={self.ver}"
         if extra != "":
             full_url += "&" + extra
-        print("Making request: " + full_url)
         r = requests.get(full_url)
         return r.text
     def do_search3(self, query):
@@ -39,18 +38,14 @@ class pysubsonic:
         for elem in song_elements:
             ids.append(elem['id'])
         return ids
+    def get_playlists(self, username=None):
+        extra = f"username={username}" if username is not None else ""
+        return self.do_request("getPlaylists", extra)
     def create_playlist(self, id=None, name=None, songid=None):
         params = f"playlistId={id}" if id is not None else ""
         params += f"&name={name}" if name is not None else ""
-        if type(songid) == str:
-            params += f"&songId={songid}"
-        elif type(songid) == list:
-            for sid in songid:
-                params += f"&songID={sid}"
+        params += f"&songId={songid}" if songid is not None else ""
         return self.do_request("createPlaylist", params)
-    def update_playlist(self, playlistId, songIdToAdd):
-        params = f"playlistId={playlistId}&songIdToAdd={songIdToAdd}"
-        return self.do_request("updatePlaylist", params)
     def parse_playlist_id(self, response_data):
         soup = BeautifulSoup(response_data, 'xml')
         pl = soup.find_all('playlist')[0]
@@ -59,8 +54,4 @@ if __name__ == "__main__":
     import getpass
     passw = getpass.getpass(prompt="Password: ")
     p = pysubsonic("https://music.xhec.dev", "matt", passw)
-    song_id = p.get_song_ids("Such Great Heights")[0]
-
-    xml = p.create_playlist(name="Test Playlist")
-    pl_id = p.parse_playlist_id(xml)
-    print(f"Created Test Playlist: {pl_id}")
\ No newline at end of file
+    print(p.get_playlists())
\ No newline at end of file
